"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import api_pb2
import auth_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import references_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _StrongVerificationAttemptStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StrongVerificationAttemptStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_StrongVerificationAttemptStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STRONG_VERIFICATION_ATTEMPT_STATUS_UNKNOWN: _StrongVerificationAttemptStatus.ValueType  # 0
    STRONG_VERIFICATION_ATTEMPT_STATUS_SUCCEEDED: _StrongVerificationAttemptStatus.ValueType  # 1
    STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_TO_OPEN_APP: _StrongVerificationAttemptStatus.ValueType  # 2
    STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_IN_APP: _StrongVerificationAttemptStatus.ValueType  # 5
    STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_BACKEND: _StrongVerificationAttemptStatus.ValueType  # 3
    STRONG_VERIFICATION_ATTEMPT_STATUS_FAILED: _StrongVerificationAttemptStatus.ValueType  # 4

class StrongVerificationAttemptStatus(_StrongVerificationAttemptStatus, metaclass=_StrongVerificationAttemptStatusEnumTypeWrapper): ...

STRONG_VERIFICATION_ATTEMPT_STATUS_UNKNOWN: StrongVerificationAttemptStatus.ValueType  # 0
STRONG_VERIFICATION_ATTEMPT_STATUS_SUCCEEDED: StrongVerificationAttemptStatus.ValueType  # 1
STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_TO_OPEN_APP: StrongVerificationAttemptStatus.ValueType  # 2
STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_IN_APP: StrongVerificationAttemptStatus.ValueType  # 5
STRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_BACKEND: StrongVerificationAttemptStatus.ValueType  # 3
STRONG_VERIFICATION_ATTEMPT_STATUS_FAILED: StrongVerificationAttemptStatus.ValueType  # 4
Global___StrongVerificationAttemptStatus: typing_extensions.TypeAlias = StrongVerificationAttemptStatus

class _ProfilePublicVisibility:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProfilePublicVisibilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ProfilePublicVisibility.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROFILE_PUBLIC_VISIBILITY_UNKNOWN: _ProfilePublicVisibility.ValueType  # 0
    PROFILE_PUBLIC_VISIBILITY_NOTHING: _ProfilePublicVisibility.ValueType  # 1
    PROFILE_PUBLIC_VISIBILITY_MAP_ONLY: _ProfilePublicVisibility.ValueType  # 2
    PROFILE_PUBLIC_VISIBILITY_LIMITED: _ProfilePublicVisibility.ValueType  # 3
    PROFILE_PUBLIC_VISIBILITY_MOST: _ProfilePublicVisibility.ValueType  # 4
    PROFILE_PUBLIC_VISIBILITY_FULL: _ProfilePublicVisibility.ValueType  # 5

class ProfilePublicVisibility(_ProfilePublicVisibility, metaclass=_ProfilePublicVisibilityEnumTypeWrapper): ...

PROFILE_PUBLIC_VISIBILITY_UNKNOWN: ProfilePublicVisibility.ValueType  # 0
PROFILE_PUBLIC_VISIBILITY_NOTHING: ProfilePublicVisibility.ValueType  # 1
PROFILE_PUBLIC_VISIBILITY_MAP_ONLY: ProfilePublicVisibility.ValueType  # 2
PROFILE_PUBLIC_VISIBILITY_LIMITED: ProfilePublicVisibility.ValueType  # 3
PROFILE_PUBLIC_VISIBILITY_MOST: ProfilePublicVisibility.ValueType  # 4
PROFILE_PUBLIC_VISIBILITY_FULL: ProfilePublicVisibility.ValueType  # 5
Global___ProfilePublicVisibility: typing_extensions.TypeAlias = ProfilePublicVisibility

@typing.final
class GetAccountInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PROFILE_COMPLETE_FIELD_NUMBER: builtins.int
    MY_HOME_COMPLETE_FIELD_NUMBER: builtins.int
    PHONE_FIELD_NUMBER: builtins.int
    PHONE_VERIFIED_FIELD_NUMBER: builtins.int
    TIMEZONE_FIELD_NUMBER: builtins.int
    HAS_DONATED_FIELD_NUMBER: builtins.int
    HAS_STRONG_VERIFICATION_FIELD_NUMBER: builtins.int
    BIRTHDATE_VERIFICATION_STATUS_FIELD_NUMBER: builtins.int
    GENDER_VERIFICATION_STATUS_FIELD_NUMBER: builtins.int
    DO_NOT_EMAIL_FIELD_NUMBER: builtins.int
    IS_SUPERUSER_FIELD_NUMBER: builtins.int
    UI_LANGUAGE_PREFERENCE_FIELD_NUMBER: builtins.int
    PROFILE_PUBLIC_VISIBILITY_FIELD_NUMBER: builtins.int
    IS_VOLUNTEER_FIELD_NUMBER: builtins.int
    SHOULD_SHOW_DONATION_BANNER_FIELD_NUMBER: builtins.int
    username: builtins.str
    email: builtins.str
    """user's current email address"""
    profile_complete: builtins.bool
    """whether the user has completed their profile; otherwise needs to display a banner on dashboard"""
    my_home_complete: builtins.bool
    """whether the user has completed their my home section"""
    phone: builtins.str
    """User's alleged phone number in E.164 format (including country code with the + sign)"""
    phone_verified: builtins.bool
    """Whether the above phone number has been successfully verified or not"""
    timezone: builtins.str
    """the user's timezone name identifier, derived from their coordinates, for example "Australia/Melbourne" """
    has_donated: builtins.bool
    has_strong_verification: builtins.bool
    """strong verification info"""
    birthdate_verification_status: api_pb2.BirthdateVerificationStatus.ValueType
    gender_verification_status: api_pb2.GenderVerificationStatus.ValueType
    do_not_email: builtins.bool
    """whether the user has all non-security emails off"""
    is_superuser: builtins.bool
    """whether the user is a superuser"""
    ui_language_preference: builtins.str
    profile_public_visibility: Global___ProfilePublicVisibility.ValueType
    is_volunteer: builtins.bool
    should_show_donation_banner: builtins.bool
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        email: builtins.str | None = ...,
        profile_complete: builtins.bool | None = ...,
        my_home_complete: builtins.bool | None = ...,
        phone: builtins.str | None = ...,
        phone_verified: builtins.bool | None = ...,
        timezone: builtins.str | None = ...,
        has_donated: builtins.bool | None = ...,
        has_strong_verification: builtins.bool | None = ...,
        birthdate_verification_status: api_pb2.BirthdateVerificationStatus.ValueType | None = ...,
        gender_verification_status: api_pb2.GenderVerificationStatus.ValueType | None = ...,
        do_not_email: builtins.bool | None = ...,
        is_superuser: builtins.bool | None = ...,
        ui_language_preference: builtins.str | None = ...,
        profile_public_visibility: Global___ProfilePublicVisibility.ValueType | None = ...,
        is_volunteer: builtins.bool | None = ...,
        should_show_donation_banner: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["birthdate_verification_status", b"birthdate_verification_status", "do_not_email", b"do_not_email", "email", b"email", "gender_verification_status", b"gender_verification_status", "has_donated", b"has_donated", "has_strong_verification", b"has_strong_verification", "is_superuser", b"is_superuser", "is_volunteer", b"is_volunteer", "my_home_complete", b"my_home_complete", "phone", b"phone", "phone_verified", b"phone_verified", "profile_complete", b"profile_complete", "profile_public_visibility", b"profile_public_visibility", "should_show_donation_banner", b"should_show_donation_banner", "timezone", b"timezone", "ui_language_preference", b"ui_language_preference", "username", b"username"]) -> None: ...

Global___GetAccountInfoRes: typing_extensions.TypeAlias = GetAccountInfoRes

@typing.final
class ChangePasswordV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_PASSWORD_FIELD_NUMBER: builtins.int
    NEW_PASSWORD_FIELD_NUMBER: builtins.int
    old_password: builtins.str
    new_password: builtins.str
    def __init__(
        self,
        *,
        old_password: builtins.str | None = ...,
        new_password: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_password", b"new_password", "old_password", b"old_password"]) -> None: ...

Global___ChangePasswordV2Req: typing_extensions.TypeAlias = ChangePasswordV2Req

@typing.final
class ChangeEmailV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_FIELD_NUMBER: builtins.int
    NEW_EMAIL_FIELD_NUMBER: builtins.int
    password: builtins.str
    new_email: builtins.str
    def __init__(
        self,
        *,
        password: builtins.str | None = ...,
        new_email: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["new_email", b"new_email", "password", b"password"]) -> None: ...

Global___ChangeEmailV2Req: typing_extensions.TypeAlias = ChangeEmailV2Req

@typing.final
class ChangeLanguagePreferenceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UI_LANGUAGE_PREFERENCE_FIELD_NUMBER: builtins.int
    ui_language_preference: builtins.str
    def __init__(
        self,
        *,
        ui_language_preference: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ui_language_preference", b"ui_language_preference"]) -> None: ...

Global___ChangeLanguagePreferenceReq: typing_extensions.TypeAlias = ChangeLanguagePreferenceReq

@typing.final
class GetContributorFormInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILLED_CONTRIBUTOR_FORM_FIELD_NUMBER: builtins.int
    filled_contributor_form: builtins.bool
    def __init__(
        self,
        *,
        filled_contributor_form: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filled_contributor_form", b"filled_contributor_form"]) -> None: ...

Global___GetContributorFormInfoRes: typing_extensions.TypeAlias = GetContributorFormInfoRes

@typing.final
class FillContributorFormReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTRIBUTOR_FORM_FIELD_NUMBER: builtins.int
    @property
    def contributor_form(self) -> auth_pb2.ContributorForm: ...
    def __init__(
        self,
        *,
        contributor_form: auth_pb2.ContributorForm | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["contributor_form", b"contributor_form"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["contributor_form", b"contributor_form"]) -> None: ...

Global___FillContributorFormReq: typing_extensions.TypeAlias = FillContributorFormReq

@typing.final
class ChangePhoneReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHONE_FIELD_NUMBER: builtins.int
    phone: builtins.str
    """New phone number in international format without spaces and punctuation,
    for example "+46701740605". Pass empty string to remove a verified phone number.
    The phone number will only be visible, once verified, to accepted guests and accepted hosts.
    """
    def __init__(
        self,
        *,
        phone: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["phone", b"phone"]) -> None: ...

Global___ChangePhoneReq: typing_extensions.TypeAlias = ChangePhoneReq

@typing.final
class VerifyPhoneReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    token: builtins.str
    """Should be a 6-digit string with Luhn algorithm mod 10 checksum equals 0.
    Frontends could do that pre-check.
    """
    def __init__(
        self,
        *,
        token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["token", b"token"]) -> None: ...

Global___VerifyPhoneReq: typing_extensions.TypeAlias = VerifyPhoneReq

@typing.final
class InitiateStrongVerificationRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERIFICATION_ATTEMPT_TOKEN_FIELD_NUMBER: builtins.int
    REDIRECT_URL_FIELD_NUMBER: builtins.int
    verification_attempt_token: builtins.str
    """use this token to check status"""
    redirect_url: builtins.str
    """this is where the user should be redirected for the next step"""
    def __init__(
        self,
        *,
        verification_attempt_token: builtins.str | None = ...,
        redirect_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["redirect_url", b"redirect_url", "verification_attempt_token", b"verification_attempt_token"]) -> None: ...

Global___InitiateStrongVerificationRes: typing_extensions.TypeAlias = InitiateStrongVerificationRes

@typing.final
class GetStrongVerificationAttemptStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERIFICATION_ATTEMPT_TOKEN_FIELD_NUMBER: builtins.int
    verification_attempt_token: builtins.str
    def __init__(
        self,
        *,
        verification_attempt_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["verification_attempt_token", b"verification_attempt_token"]) -> None: ...

Global___GetStrongVerificationAttemptStatusReq: typing_extensions.TypeAlias = GetStrongVerificationAttemptStatusReq

@typing.final
class GetStrongVerificationAttemptStatusRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___StrongVerificationAttemptStatus.ValueType
    def __init__(
        self,
        *,
        status: Global___StrongVerificationAttemptStatus.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

Global___GetStrongVerificationAttemptStatusRes: typing_extensions.TypeAlias = GetStrongVerificationAttemptStatusRes

@typing.final
class DeleteAccountReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIRM_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    confirm: builtins.bool
    reason: builtins.str
    def __init__(
        self,
        *,
        confirm: builtins.bool | None = ...,
        reason: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confirm", b"confirm", "reason", b"reason"]) -> None: ...

Global___DeleteAccountReq: typing_extensions.TypeAlias = DeleteAccountReq

@typing.final
class ModNote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTE_ID_FIELD_NUMBER: builtins.int
    NOTE_CONTENT_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    ACKNOWLEDGED_FIELD_NUMBER: builtins.int
    note_id: builtins.int
    """used in ack"""
    note_content: builtins.str
    """CommonMark without images"""
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def acknowledged(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """will be empty if pending"""

    def __init__(
        self,
        *,
        note_id: builtins.int | None = ...,
        note_content: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        acknowledged: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["acknowledged", b"acknowledged", "created", b"created"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acknowledged", b"acknowledged", "created", b"created", "note_content", b"note_content", "note_id", b"note_id"]) -> None: ...

Global___ModNote: typing_extensions.TypeAlias = ModNote

@typing.final
class ListModNotesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MOD_NOTES_FIELD_NUMBER: builtins.int
    @property
    def mod_notes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ModNote]: ...
    def __init__(
        self,
        *,
        mod_notes: collections.abc.Iterable[Global___ModNote] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mod_notes", b"mod_notes"]) -> None: ...

Global___ListModNotesRes: typing_extensions.TypeAlias = ListModNotesRes

@typing.final
class ListActiveSessionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListActiveSessionsReq: typing_extensions.TypeAlias = ListActiveSessionsReq

@typing.final
class ActiveSession(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    LAST_SEEN_FIELD_NUMBER: builtins.int
    OPERATING_SYSTEM_FIELD_NUMBER: builtins.int
    BROWSER_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    APPROXIMATE_LOCATION_FIELD_NUMBER: builtins.int
    IS_CURRENT_SESSION_FIELD_NUMBER: builtins.int
    operating_system: builtins.str
    browser: builtins.str
    device: builtins.str
    approximate_location: builtins.str
    is_current_session: builtins.bool
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def expiry(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_seen(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expiry: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_seen: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        operating_system: builtins.str | None = ...,
        browser: builtins.str | None = ...,
        device: builtins.str | None = ...,
        approximate_location: builtins.str | None = ...,
        is_current_session: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "expiry", b"expiry", "last_seen", b"last_seen"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["approximate_location", b"approximate_location", "browser", b"browser", "created", b"created", "device", b"device", "expiry", b"expiry", "is_current_session", b"is_current_session", "last_seen", b"last_seen", "operating_system", b"operating_system"]) -> None: ...

Global___ActiveSession: typing_extensions.TypeAlias = ActiveSession

@typing.final
class ListActiveSessionsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_SESSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def active_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ActiveSession]: ...
    def __init__(
        self,
        *,
        active_sessions: collections.abc.Iterable[Global___ActiveSession] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["active_sessions", b"active_sessions", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListActiveSessionsRes: typing_extensions.TypeAlias = ListActiveSessionsRes

@typing.final
class LogOutSessionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_FIELD_NUMBER: builtins.int
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created", b"created"]) -> None: ...

Global___LogOutSessionReq: typing_extensions.TypeAlias = LogOutSessionReq

@typing.final
class LogOutOtherSessionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIRM_FIELD_NUMBER: builtins.int
    confirm: builtins.bool
    def __init__(
        self,
        *,
        confirm: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confirm", b"confirm"]) -> None: ...

Global___LogOutOtherSessionsReq: typing_extensions.TypeAlias = LogOutOtherSessionsReq

@typing.final
class SetProfilePublicVisibilityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROFILE_PUBLIC_VISIBILITY_FIELD_NUMBER: builtins.int
    profile_public_visibility: Global___ProfilePublicVisibility.ValueType
    def __init__(
        self,
        *,
        profile_public_visibility: Global___ProfilePublicVisibility.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["profile_public_visibility", b"profile_public_visibility"]) -> None: ...

Global___SetProfilePublicVisibilityReq: typing_extensions.TypeAlias = SetProfilePublicVisibilityReq

@typing.final
class CreateInviteCodeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CreateInviteCodeReq: typing_extensions.TypeAlias = CreateInviteCodeReq

@typing.final
class CreateInviteCodeRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    code: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
        url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "url", b"url"]) -> None: ...

Global___CreateInviteCodeRes: typing_extensions.TypeAlias = CreateInviteCodeRes

@typing.final
class DisableInviteCodeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.str
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code"]) -> None: ...

Global___DisableInviteCodeReq: typing_extensions.TypeAlias = DisableInviteCodeReq

@typing.final
class InviteCodeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    USES_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    code: builtins.str
    uses: builtins.int
    url: builtins.str
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def disabled(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        code: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        disabled: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        uses: builtins.int | None = ...,
        url: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "disabled", b"disabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "created", b"created", "disabled", b"disabled", "url", b"url", "uses", b"uses"]) -> None: ...

Global___InviteCodeInfo: typing_extensions.TypeAlias = InviteCodeInfo

@typing.final
class ListInviteCodesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVITE_CODES_FIELD_NUMBER: builtins.int
    @property
    def invite_codes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___InviteCodeInfo]: ...
    def __init__(
        self,
        *,
        invite_codes: collections.abc.Iterable[Global___InviteCodeInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["invite_codes", b"invite_codes"]) -> None: ...

Global___ListInviteCodesRes: typing_extensions.TypeAlias = ListInviteCodesRes

@typing.final
class CompleteProfileReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CompleteProfileReminder: typing_extensions.TypeAlias = CompleteProfileReminder

@typing.final
class CompleteVerificationReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___CompleteVerificationReminder: typing_extensions.TypeAlias = CompleteVerificationReminder

@typing.final
class RespondToHostRequestReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    SURFER_USER_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    @property
    def surfer_user(self) -> api_pb2.LiteUser: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        surfer_user: api_pb2.LiteUser | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["surfer_user", b"surfer_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request_id", b"host_request_id", "surfer_user", b"surfer_user"]) -> None: ...

Global___RespondToHostRequestReminder: typing_extensions.TypeAlias = RespondToHostRequestReminder

@typing.final
class WriteReferenceReminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    OTHER_USER_FIELD_NUMBER: builtins.int
    REFERENCE_TYPE_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    reference_type: references_pb2.ReferenceType.ValueType
    @property
    def other_user(self) -> api_pb2.LiteUser: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        other_user: api_pb2.LiteUser | None = ...,
        reference_type: references_pb2.ReferenceType.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["other_user", b"other_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["host_request_id", b"host_request_id", "other_user", b"other_user", "reference_type", b"reference_type"]) -> None: ...

Global___WriteReferenceReminder: typing_extensions.TypeAlias = WriteReferenceReminder

@typing.final
class Reminder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPLETE_PROFILE_REMINDER_FIELD_NUMBER: builtins.int
    COMPLETE_VERIFICATION_REMINDER_FIELD_NUMBER: builtins.int
    RESPOND_TO_HOST_REQUEST_REMINDER_FIELD_NUMBER: builtins.int
    WRITE_REFERENCE_REMINDER_FIELD_NUMBER: builtins.int
    @property
    def complete_profile_reminder(self) -> Global___CompleteProfileReminder: ...
    @property
    def complete_verification_reminder(self) -> Global___CompleteVerificationReminder: ...
    @property
    def respond_to_host_request_reminder(self) -> Global___RespondToHostRequestReminder: ...
    @property
    def write_reference_reminder(self) -> Global___WriteReferenceReminder: ...
    def __init__(
        self,
        *,
        complete_profile_reminder: Global___CompleteProfileReminder | None = ...,
        complete_verification_reminder: Global___CompleteVerificationReminder | None = ...,
        respond_to_host_request_reminder: Global___RespondToHostRequestReminder | None = ...,
        write_reference_reminder: Global___WriteReferenceReminder | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["complete_profile_reminder", b"complete_profile_reminder", "complete_verification_reminder", b"complete_verification_reminder", "reminder", b"reminder", "respond_to_host_request_reminder", b"respond_to_host_request_reminder", "write_reference_reminder", b"write_reference_reminder"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["complete_profile_reminder", b"complete_profile_reminder", "complete_verification_reminder", b"complete_verification_reminder", "reminder", b"reminder", "respond_to_host_request_reminder", b"respond_to_host_request_reminder", "write_reference_reminder", b"write_reference_reminder"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["reminder", b"reminder"]) -> typing.Literal["complete_profile_reminder", "complete_verification_reminder", "respond_to_host_request_reminder", "write_reference_reminder"] | None: ...

Global___Reminder: typing_extensions.TypeAlias = Reminder

@typing.final
class GetRemindersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMINDERS_FIELD_NUMBER: builtins.int
    @property
    def reminders(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Reminder]:
        """items are returned in order from most important to least important and should be displayed as such"""

    def __init__(
        self,
        *,
        reminders: collections.abc.Iterable[Global___Reminder] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["reminders", b"reminders"]) -> None: ...

Global___GetRemindersRes: typing_extensions.TypeAlias = GetRemindersRes

@typing.final
class GetMyVolunteerInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    DISPLAY_LOCATION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    STARTED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    STOPPED_VOLUNTEERING_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    """empty for missing"""
    display_location: builtins.str
    role: builtins.str
    """volunteer defined role"""
    started_volunteering: builtins.str
    """dates as "yyyy-mm-dd" """
    stopped_volunteering: builtins.str
    show_on_team_page: builtins.bool
    link_type: builtins.str
    """link type, one of couchers, email, linkedin, website"""
    link_text: builtins.str
    """the text to be shown on the link"""
    link_url: builtins.str
    """the URL the link should take you to"""
    def __init__(
        self,
        *,
        display_name: builtins.str | None = ...,
        display_location: builtins.str | None = ...,
        role: builtins.str | None = ...,
        started_volunteering: builtins.str | None = ...,
        stopped_volunteering: builtins.str | None = ...,
        show_on_team_page: builtins.bool | None = ...,
        link_type: builtins.str | None = ...,
        link_text: builtins.str | None = ...,
        link_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["display_location", b"display_location", "display_name", b"display_name", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "role", b"role", "show_on_team_page", b"show_on_team_page", "started_volunteering", b"started_volunteering", "stopped_volunteering", b"stopped_volunteering"]) -> None: ...

Global___GetMyVolunteerInfoRes: typing_extensions.TypeAlias = GetMyVolunteerInfoRes

@typing.final
class UpdateMyVolunteerInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    DISPLAY_LOCATION_FIELD_NUMBER: builtins.int
    SHOW_ON_TEAM_PAGE_FIELD_NUMBER: builtins.int
    LINK_TYPE_FIELD_NUMBER: builtins.int
    LINK_TEXT_FIELD_NUMBER: builtins.int
    LINK_URL_FIELD_NUMBER: builtins.int
    @property
    def display_name(self) -> google.protobuf.wrappers_pb2.StringValue:
        """empty for missing"""

    @property
    def display_location(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def show_on_team_page(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def link_type(self) -> google.protobuf.wrappers_pb2.StringValue:
        """link type, one of email, linkedin, website"""

    @property
    def link_text(self) -> google.protobuf.wrappers_pb2.StringValue:
        """the text to be shown on the link"""

    @property
    def link_url(self) -> google.protobuf.wrappers_pb2.StringValue:
        """the URL the link should take you to"""

    def __init__(
        self,
        *,
        display_name: google.protobuf.wrappers_pb2.StringValue | None = ...,
        display_location: google.protobuf.wrappers_pb2.StringValue | None = ...,
        show_on_team_page: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        link_type: google.protobuf.wrappers_pb2.StringValue | None = ...,
        link_text: google.protobuf.wrappers_pb2.StringValue | None = ...,
        link_url: google.protobuf.wrappers_pb2.StringValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["display_location", b"display_location", "display_name", b"display_name", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "show_on_team_page", b"show_on_team_page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["display_location", b"display_location", "display_name", b"display_name", "link_text", b"link_text", "link_type", b"link_type", "link_url", b"link_url", "show_on_team_page", b"show_on_team_page"]) -> None: ...

Global___UpdateMyVolunteerInfoReq: typing_extensions.TypeAlias = UpdateMyVolunteerInfoReq



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: threads.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rthreads.proto\x12\x18org.couchers.api.threads\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"2\n\x06Thread\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x15\n\rnum_responses\x18\x02 \x01(\x03\"H\n\x0cGetThreadReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Y\n\x0cGetThreadRes\x12\x30\n\x07replies\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\x8a\x01\n\x05Reply\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthor_user_id\x18\x03 \x01(\x03\x12\x30\n\x0c\x63reated_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnum_replies\x18\x05 \x01(\r\"2\n\x0cPostReplyReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"!\n\x0cPostReplyRes\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x32\xc9\x01\n\x07Threads\x12[\n\tGetThread\x12&.org.couchers.api.threads.GetThreadReq\x1a&.org.couchers.api.threads.GetThreadRes\x12[\n\tPostReply\x12&.org.couchers.api.threads.PostReplyReq\x1a&.org.couchers.api.threads.PostReplyRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'threads_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREADS']._loaded_options = None
  _globals['_THREADS']._serialized_options = b'\210\265\030\003'
  _globals['_THREAD']._serialized_start=95
  _globals['_THREAD']._serialized_end=145
  _globals['_GETTHREADREQ']._serialized_start=147
  _globals['_GETTHREADREQ']._serialized_end=219
  _globals['_GETTHREADRES']._serialized_start=221
  _globals['_GETTHREADRES']._serialized_end=310
  _globals['_REPLY']._serialized_start=313
  _globals['_REPLY']._serialized_end=451
  _globals['_POSTREPLYREQ']._serialized_start=453
  _globals['_POSTREPLYREQ']._serialized_end=503
  _globals['_POSTREPLYRES']._serialized_start=505
  _globals['_POSTREPLYRES']._serialized_end=538
  _globals['_THREADS']._serialized_start=541
  _globals['_THREADS']._serialized_end=742
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification_data.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import requests_pb2 as requests__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17notification_data.proto\x12\x1eorg.couchers.notification_data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0erequests.proto\x1a\rthreads.proto\"\x8c\x01\n\x11HostRequestCreate\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\"|\n\x11HostRequestAccept\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04host\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"|\n\x11HostRequestReject\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04host\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\x7f\n\x12HostRequestConfirm\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"~\n\x11HostRequestCancel\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\x9c\x01\n\x12HostRequestMessage\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0f\n\x07\x61m_host\x18\x04 \x01(\x08\"\x95\x01\n\x19HostRequestMissedMessages\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0f\n\x07\x61m_host\x18\x03 \x01(\x08\"\x80\x01\n\x13HostRequestReminder\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"K\n\x08\x42\x61\x64geAdd\x12\x10\n\x08\x62\x61\x64ge_id\x18\x01 \x01(\t\x12\x12\n\nbadge_name\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61\x64ge_description\x18\x03 \x01(\t\"N\n\x0b\x42\x61\x64geRemove\x12\x10\n\x08\x62\x61\x64ge_id\x18\x01 \x01(\t\x12\x12\n\nbadge_name\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61\x64ge_description\x18\x03 \x01(\t\"\"\n\x11PhoneNumberChange\x12\r\n\x05phone\x18\x01 \x01(\t\"\"\n\x11PhoneNumberVerify\x12\r\n\x05phone\x18\x01 \x01(\t\"\x1e\n\x0cGenderChange\x12\x0e\n\x06gender\x18\x01 \x01(\t\"$\n\x0f\x42irthdateChange\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"F\n\x13\x46riendRequestCreate\x12/\n\nother_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"F\n\x13\x46riendRequestAccept\x12/\n\nother_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\'\n\x12\x45mailAddressChange\x12\x11\n\tnew_email\x18\x01 \x01(\t\"7\n\x10\x44onationReceived\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x03\x12\x13\n\x0breceipt_url\x18\x02 \x01(\t\"2\n\x12PasswordResetStart\x12\x1c\n\x14password_reset_token\x18\x01 \x01(\t\".\n\x14\x41\x63\x63ountDeletionStart\x12\x16\n\x0e\x64\x65letion_token\x18\x01 \x01(\t\"H\n\x17\x41\x63\x63ountDeletionComplete\x12\x16\n\x0eundelete_token\x18\x01 \x01(\t\x12\x15\n\rundelete_days\x18\x02 \x01(\r\"K\n\x0c\x41piKeyCreate\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"y\n\x14\x45ventInviteOrganizer\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rinviting_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xda\x01\n\x0b\x45ventCreate\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rinviting_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x10\n\x06nearby\x18\x03 \x01(\x08H\x00\x12?\n\x0cin_community\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x42\x15\n\x13notification_reason\"\x87\x01\n\x0b\x45ventUpdate\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rupdating_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x15\n\rupdated_items\x18\x03 \x03(\t\"r\n\x0b\x45ventCancel\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x34\n\x0f\x63\x61ncelling_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"<\n\x0b\x45ventDelete\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\"p\n\x0b\x43hatMessage\x12+\n\x06\x61uthor\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x15\n\rgroup_chat_id\x18\x04 \x01(\x04\"S\n\x12\x43hatMissedMessages\x12=\n\x08messages\x18\x01 \x03(\x0b\x32+.org.couchers.notification_data.ChatMessage\"V\n\x16ReferenceReceiveFriend\x12.\n\tfrom_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x02 \x01(\t\"t\n\x1bReferenceReceiveHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12.\n\tfrom_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\"p\n\x11ReferenceReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12/\n\nother_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x11\n\tdays_left\x18\x03 \x01(\r\"i\n\rEventReminder\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"R\n\x12VerificationSVFail\x12<\n\x06reason\x18\x01 \x01(\x0e\x32,.org.couchers.notification_data.SVFailReason\"?\n\x1ePostalVerificationPostcardSent\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\"h\n\x18PostalVerificationFailed\x12L\n\x06reason\x18\x01 \x01(\x0e\x32<.org.couchers.notification_data.PostalVerificationFailReason\"\x9a\x01\n\x0c\x45ventComment\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12-\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12+\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"}\n\x10\x44iscussionCreate\x12<\n\ndiscussion\x18\x01 \x01(\x0b\x32(.org.couchers.api.discussions.Discussion\x12+\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xae\x01\n\x11\x44iscussionComment\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12<\n\ndiscussion\x18\x02 \x01(\x0b\x32(.org.couchers.api.discussions.Discussion\x12+\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xeb\x01\n\x0bThreadReply\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12+\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x12>\n\ndiscussion\x18\x04 \x01(\x0b\x32(.org.couchers.api.discussions.DiscussionH\x00\x42\x0e\n\x0creply_parent\"X\n\x0f\x41\x63tivenessProbe\x12\x17\n\x0freminder_number\x18\x01 \x01(\x04\x12,\n\x08\x64\x65\x61\x64line\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x12GeneralNewBlogPost\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x62lurb\x18\x03 \x01(\t*\x99\x01\n\x0cSVFailReason\x12\x1a\n\x16SV_FAIL_REASON_UNKNOWN\x10\x00\x12,\n(SV_FAIL_REASON_WRONG_BIRTHDATE_OR_GENDER\x10\x01\x12!\n\x1dSV_FAIL_REASON_NOT_A_PASSPORT\x10\x02\x12\x1c\n\x18SV_FAIL_REASON_DUPLICATE\x10\x03*\xb4\x01\n\x1cPostalVerificationFailReason\x12+\n\'POSTAL_VERIFICATION_FAIL_REASON_UNKNOWN\x10\x00\x12\x30\n,POSTAL_VERIFICATION_FAIL_REASON_CODE_EXPIRED\x10\x01\x12\x35\n1POSTAL_VERIFICATION_FAIL_REASON_TOO_MANY_ATTEMPTS\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SVFAILREASON']._serialized_start=4468
  _globals['_SVFAILREASON']._serialized_end=4621
  _globals['_POSTALVERIFICATIONFAILREASON']._serialized_start=4624
  _globals['_POSTALVERIFICATIONFAILREASON']._serialized_end=4804
  _globals['_HOSTREQUESTCREATE']._serialized_start=187
  _globals['_HOSTREQUESTCREATE']._serialized_end=327
  _globals['_HOSTREQUESTACCEPT']._serialized_start=329
  _globals['_HOSTREQUESTACCEPT']._serialized_end=453
  _globals['_HOSTREQUESTREJECT']._serialized_start=455
  _globals['_HOSTREQUESTREJECT']._serialized_end=579
  _globals['_HOSTREQUESTCONFIRM']._serialized_start=581
  _globals['_HOSTREQUESTCONFIRM']._serialized_end=708
  _globals['_HOSTREQUESTCANCEL']._serialized_start=710
  _globals['_HOSTREQUESTCANCEL']._serialized_end=836
  _globals['_HOSTREQUESTMESSAGE']._serialized_start=839
  _globals['_HOSTREQUESTMESSAGE']._serialized_end=995
  _globals['_HOSTREQUESTMISSEDMESSAGES']._serialized_start=998
  _globals['_HOSTREQUESTMISSEDMESSAGES']._serialized_end=1147
  _globals['_HOSTREQUESTREMINDER']._serialized_start=1150
  _globals['_HOSTREQUESTREMINDER']._serialized_end=1278
  _globals['_BADGEADD']._serialized_start=1280
  _globals['_BADGEADD']._serialized_end=1355
  _globals['_BADGEREMOVE']._serialized_start=1357
  _globals['_BADGEREMOVE']._serialized_end=1435
  _globals['_PHONENUMBERCHANGE']._serialized_start=1437
  _globals['_PHONENUMBERCHANGE']._serialized_end=1471
  _globals['_PHONENUMBERVERIFY']._serialized_start=1473
  _globals['_PHONENUMBERVERIFY']._serialized_end=1507
  _globals['_GENDERCHANGE']._serialized_start=1509
  _globals['_GENDERCHANGE']._serialized_end=1539
  _globals['_BIRTHDATECHANGE']._serialized_start=1541
  _globals['_BIRTHDATECHANGE']._serialized_end=1577
  _globals['_FRIENDREQUESTCREATE']._serialized_start=1579
  _globals['_FRIENDREQUESTCREATE']._serialized_end=1649
  _globals['_FRIENDREQUESTACCEPT']._serialized_start=1651
  _globals['_FRIENDREQUESTACCEPT']._serialized_end=1721
  _globals['_EMAILADDRESSCHANGE']._serialized_start=1723
  _globals['_EMAILADDRESSCHANGE']._serialized_end=1762
  _globals['_DONATIONRECEIVED']._serialized_start=1764
  _globals['_DONATIONRECEIVED']._serialized_end=1819
  _globals['_PASSWORDRESETSTART']._serialized_start=1821
  _globals['_PASSWORDRESETSTART']._serialized_end=1871
  _globals['_ACCOUNTDELETIONSTART']._serialized_start=1873
  _globals['_ACCOUNTDELETIONSTART']._serialized_end=1919
  _globals['_ACCOUNTDELETIONCOMPLETE']._serialized_start=1921
  _globals['_ACCOUNTDELETIONCOMPLETE']._serialized_end=1993
  _globals['_APIKEYCREATE']._serialized_start=1995
  _globals['_APIKEYCREATE']._serialized_end=2070
  _globals['_EVENTINVITEORGANIZER']._serialized_start=2072
  _globals['_EVENTINVITEORGANIZER']._serialized_end=2193
  _globals['_EVENTCREATE']._serialized_start=2196
  _globals['_EVENTCREATE']._serialized_end=2414
  _globals['_EVENTUPDATE']._serialized_start=2417
  _globals['_EVENTUPDATE']._serialized_end=2552
  _globals['_EVENTCANCEL']._serialized_start=2554
  _globals['_EVENTCANCEL']._serialized_end=2668
  _globals['_EVENTDELETE']._serialized_start=2670
  _globals['_EVENTDELETE']._serialized_end=2730
  _globals['_CHATMESSAGE']._serialized_start=2732
  _globals['_CHATMESSAGE']._serialized_end=2844
  _globals['_CHATMISSEDMESSAGES']._serialized_start=2846
  _globals['_CHATMISSEDMESSAGES']._serialized_end=2929
  _globals['_REFERENCERECEIVEFRIEND']._serialized_start=2931
  _globals['_REFERENCERECEIVEFRIEND']._serialized_end=3017
  _globals['_REFERENCERECEIVEHOSTREQUEST']._serialized_start=3019
  _globals['_REFERENCERECEIVEHOSTREQUEST']._serialized_end=3135
  _globals['_REFERENCEREMINDER']._serialized_start=3137
  _globals['_REFERENCEREMINDER']._serialized_end=3249
  _globals['_EVENTREMINDER']._serialized_start=3251
  _globals['_EVENTREMINDER']._serialized_end=3356
  _globals['_VERIFICATIONSVFAIL']._serialized_start=3358
  _globals['_VERIFICATIONSVFAIL']._serialized_end=3440
  _globals['_POSTALVERIFICATIONPOSTCARDSENT']._serialized_start=3442
  _globals['_POSTALVERIFICATIONPOSTCARDSENT']._serialized_end=3505
  _globals['_POSTALVERIFICATIONFAILED']._serialized_start=3507
  _globals['_POSTALVERIFICATIONFAILED']._serialized_end=3611
  _globals['_EVENTCOMMENT']._serialized_start=3614
  _globals['_EVENTCOMMENT']._serialized_end=3768
  _globals['_DISCUSSIONCREATE']._serialized_start=3770
  _globals['_DISCUSSIONCREATE']._serialized_end=3895
  _globals['_DISCUSSIONCOMMENT']._serialized_start=3898
  _globals['_DISCUSSIONCOMMENT']._serialized_end=4072
  _globals['_THREADREPLY']._serialized_start=4075
  _globals['_THREADREPLY']._serialized_end=4310
  _globals['_ACTIVENESSPROBE']._serialized_start=4312
  _globals['_ACTIVENESSPROBE']._serialized_end=4400
  _globals['_GENERALNEWBLOGPOST']._serialized_start=4402
  _globals['_GENERALNEWBLOGPOST']._serialized_end=4465
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.api.httpbody_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import public_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class PublicServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetPublicUsers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.api.httpbody_pb2.HttpBody, collections.abc.Awaitable[google.api.httpbody_pb2.HttpBody]]: ...

    @abc.abstractmethod
    def GetPublicUser(
        self,
        request: public_pb2.GetPublicUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetPublicUserRes, collections.abc.Awaitable[public_pb2.GetPublicUserRes]]: ...

    @abc.abstractmethod
    def GetSignupPageInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetSignupPageInfoRes, collections.abc.Awaitable[public_pb2.GetSignupPageInfoRes]]: ...

    @abc.abstractmethod
    def GetVolunteers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetVolunteersRes, collections.abc.Awaitable[public_pb2.GetVolunteersRes]]: ...

    @abc.abstractmethod
    def GetDonationStats(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetDonationStatsRes, collections.abc.Awaitable[public_pb2.GetDonationStatsRes]]: ...

def add_PublicServicer_to_server(servicer: PublicServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import auth_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class AuthServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SignupFlow(
        self,
        request: auth_pb2.SignupFlowReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.SignupFlowRes, collections.abc.Awaitable[auth_pb2.SignupFlowRes]]:
        """
        Authentication API

        This API facilitates authentication actions: signup and signin. Users need to use this before logging in, so you don't
        need to be authorized to use it.

        The signup flow is as follows:
        A user enters their email and submits a form, which fires off a Signup call
        Signup validates the email isn't in the database yet, creates a signup_token, and emails it to the email address
        User clicks on the signup link, which brings them onto the signup completion form
        When this form loads, the app queries SignupTokenInfo for the email address associated to that login token to
        display in the UI
        User chooses a username (possibly querying UsernameValid to check possibly usernames) and fills in other basic
        information
        User submits the signup completion form, which validates this input, creates the user and logs them in, returns a
        session token (signup token is invalidated)

        The login flow is as follows:
        User types in username and password and the frontend calls Authenticate

        Signup tokens expire after some time, and once used cannot be reused.

        There can be multiple signup requests simultaneously with the same email address. Email address uniqueness is checked
        once when creating the signup request, and again when creating the user.

        The signup flow (from point of view of backend) is as follows:
        * There are three parts to the signup: Basic, Account, and Feedback
        * Each part needs to be filled in, and the user's email needs to be confirmed before the user can continue to the
        app
        * The Basic part must be filled in in the first request, after which the backend returns a flow_token
        * The frontend may do the signup incrementally by sending the other parts with the same flow_token
        * You can only fill in each part once
        * You can get info on the flow_token by sending an empty request with just the flow_token
        * Once the flow completes, the user is logged in and the signup flow is destroyed
        """

    @abc.abstractmethod
    def UsernameValid(
        self,
        request: auth_pb2.UsernameValidReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.UsernameValidRes, collections.abc.Awaitable[auth_pb2.UsernameValidRes]]:
        """Check whether the username is valid and available"""

    @abc.abstractmethod
    def Authenticate(
        self,
        request: auth_pb2.AuthReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.AuthRes, collections.abc.Awaitable[auth_pb2.AuthRes]]:
        """Log in with username + password"""

    @abc.abstractmethod
    def GetAuthState(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.GetAuthStateRes, collections.abc.Awaitable[auth_pb2.GetAuthStateRes]]:
        """Get info on current authentication state
        we need this because the web client does not have access to the non-JS cookie that contains this info, so it
        needs to be validated against the backend
        """

    @abc.abstractmethod
    def Deauthenticate(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Invalidate a session, deauthing a user"""

    @abc.abstractmethod
    def ResetPassword(
        self,
        request: auth_pb2.ResetPasswordReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Sends a forgot password email to the given user if the user exists, returns no output (so you can't go around
        guessing email addresses)
        """

    @abc.abstractmethod
    def CompletePasswordResetV2(
        self,
        request: auth_pb2.CompletePasswordResetV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.AuthRes, collections.abc.Awaitable[auth_pb2.AuthRes]]:
        """Triggered when the user goes to the link sent in the forgot password email, and logs the user in

        Actually changes the user's password
        """

    @abc.abstractmethod
    def ConfirmChangeEmailV2(
        self,
        request: auth_pb2.ConfirmChangeEmailV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Triggered when the user goes to the link sent in the either email_changed_confirmation_*_email"""

    @abc.abstractmethod
    def ConfirmDeleteAccount(
        self,
        request: auth_pb2.ConfirmDeleteAccountReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Confirms deletion of a user using a token"""

    @abc.abstractmethod
    def RecoverAccount(
        self,
        request: auth_pb2.RecoverAccountReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Recovers a recently deleted account"""

    @abc.abstractmethod
    def Unsubscribe(
        self,
        request: auth_pb2.UnsubscribeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.UnsubscribeRes, collections.abc.Awaitable[auth_pb2.UnsubscribeRes]]:
        """Handle an unsubscribe action from an email"""

    @abc.abstractmethod
    def AntiBot(
        self,
        request: auth_pb2.AntiBotReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.AntiBotRes, collections.abc.Awaitable[auth_pb2.AntiBotRes]]:
        """Send google recaptcha info asynchronously"""

    @abc.abstractmethod
    def AntiBotPolicy(
        self,
        request: auth_pb2.AntiBotPolicyReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.AntiBotPolicyRes, collections.abc.Awaitable[auth_pb2.AntiBotPolicyRes]]: ...

    @abc.abstractmethod
    def GetInviteCodeInfo(
        self,
        request: auth_pb2.GetInviteCodeInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[auth_pb2.GetInviteCodeInfoRes, collections.abc.Awaitable[auth_pb2.GetInviteCodeInfoRes]]:
        """Returns basic profile of the invite code creator: name, username, avatar_url"""

def add_AuthServicer_to_server(servicer: AuthServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import threads_pb2
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Discussion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCUSSION_ID_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    CREATOR_USER_ID_FIELD_NUMBER: builtins.int
    OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    OWNER_TITLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    CAN_MODERATE_FIELD_NUMBER: builtins.int
    discussion_id: builtins.int
    slug: builtins.str
    creator_user_id: builtins.int
    owner_community_id: builtins.int
    owner_group_id: builtins.int
    owner_title: builtins.str
    """name of community/group that this belongs in"""
    title: builtins.str
    content: builtins.str
    can_moderate: builtins.bool
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def thread(self) -> threads_pb2.Thread: ...
    def __init__(
        self,
        *,
        discussion_id: builtins.int | None = ...,
        slug: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        creator_user_id: builtins.int | None = ...,
        owner_community_id: builtins.int | None = ...,
        owner_group_id: builtins.int | None = ...,
        owner_title: builtins.str | None = ...,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        thread: threads_pb2.Thread | None = ...,
        can_moderate: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "thread", b"thread"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["can_moderate", b"can_moderate", "content", b"content", "created", b"created", "creator_user_id", b"creator_user_id", "discussion_id", b"discussion_id", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "owner_title", b"owner_title", "slug", b"slug", "thread", b"thread", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["owner", b"owner"]) -> typing.Literal["owner_community_id", "owner_group_id"] | None: ...

Global___Discussion: typing_extensions.TypeAlias = Discussion

@typing.final
class CreateDiscussionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    OWNER_COMMUNITY_ID_FIELD_NUMBER: builtins.int
    OWNER_GROUP_ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    content: builtins.str
    owner_community_id: builtins.int
    owner_group_id: builtins.int
    def __init__(
        self,
        *,
        title: builtins.str | None = ...,
        content: builtins.str | None = ...,
        owner_community_id: builtins.int | None = ...,
        owner_group_id: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "owner", b"owner", "owner_community_id", b"owner_community_id", "owner_group_id", b"owner_group_id", "title", b"title"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["owner", b"owner"]) -> typing.Literal["owner_community_id", "owner_group_id"] | None: ...

Global___CreateDiscussionReq: typing_extensions.TypeAlias = CreateDiscussionReq

@typing.final
class GetDiscussionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCUSSION_ID_FIELD_NUMBER: builtins.int
    discussion_id: builtins.int
    def __init__(
        self,
        *,
        discussion_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["discussion_id", b"discussion_id"]) -> None: ...

Global___GetDiscussionReq: typing_extensions.TypeAlias = GetDiscussionReq



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import notifications_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class NotificationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNotificationSettings(
        self,
        request: notifications_pb2.GetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetNotificationSettingsRes, collections.abc.Awaitable[notifications_pb2.GetNotificationSettingsRes]]: ...

    @abc.abstractmethod
    def SetNotificationSettings(
        self,
        request: notifications_pb2.SetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetNotificationSettingsRes, collections.abc.Awaitable[notifications_pb2.GetNotificationSettingsRes]]: ...

    @abc.abstractmethod
    def ListNotifications(
        self,
        request: notifications_pb2.ListNotificationsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.ListNotificationsRes, collections.abc.Awaitable[notifications_pb2.ListNotificationsRes]]: ...

    @abc.abstractmethod
    def MarkNotificationSeen(
        self,
        request: notifications_pb2.MarkNotificationSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def MarkAllNotificationsSeen(
        self,
        request: notifications_pb2.MarkAllNotificationsSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def GetVapidPublicKey(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetVapidPublicKeyRes, collections.abc.Awaitable[notifications_pb2.GetVapidPublicKeyRes]]: ...

    @abc.abstractmethod
    def RegisterPushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterPushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def SendTestPushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def RegisterMobilePushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterMobilePushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def SendTestMobilePushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

def add_NotificationsServicer_to_server(servicer: NotificationsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import conversations_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class ConversationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListGroupChats(
        self,
        request: conversations_pb2.ListGroupChatsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.ListGroupChatsRes, collections.abc.Awaitable[conversations_pb2.ListGroupChatsRes]]:
        """Retrieves list of group chats (ordered by last message), paginated"""

    @abc.abstractmethod
    def GetGroupChat(
        self,
        request: conversations_pb2.GetGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.GroupChat, collections.abc.Awaitable[conversations_pb2.GroupChat]]:
        """Retrieves group chat info by id"""

    @abc.abstractmethod
    def GetDirectMessage(
        self,
        request: conversations_pb2.GetDirectMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.GroupChat, collections.abc.Awaitable[conversations_pb2.GroupChat]]:
        """Retrieves group chat info for the unique (if any) direct message with a
        given user

        Raises: NOT_FOUND if there is no such direct message thread
        """

    @abc.abstractmethod
    def GetUpdates(
        self,
        request: conversations_pb2.GetUpdatesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.GetUpdatesRes, collections.abc.Awaitable[conversations_pb2.GetUpdatesRes]]:
        """Returns all new messages (aka updates) since a given message id"""

    @abc.abstractmethod
    def GetGroupChatMessages(
        self,
        request: conversations_pb2.GetGroupChatMessagesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.GetGroupChatMessagesRes, collections.abc.Awaitable[conversations_pb2.GetGroupChatMessagesRes]]:
        """Retrieves messages in group chat, paginated"""

    @abc.abstractmethod
    def MarkLastSeenGroupChat(
        self,
        request: conversations_pb2.MarkLastSeenGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Marks the last message that has been seen in this group chat"""

    @abc.abstractmethod
    def MuteGroupChat(
        self,
        request: conversations_pb2.MuteGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Mutes or unmutes a group chat
        when muted, you don't get notifications from that group chat
        """

    @abc.abstractmethod
    def CreateGroupChat(
        self,
        request: conversations_pb2.CreateGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.GroupChat, collections.abc.Awaitable[conversations_pb2.GroupChat]]:
        """Creates a new group chat"""

    @abc.abstractmethod
    def EditGroupChat(
        self,
        request: conversations_pb2.EditGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Modifies group chat"""

    @abc.abstractmethod
    def InviteToGroupChat(
        self,
        request: conversations_pb2.InviteToGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Invite a person to a chat"""

    @abc.abstractmethod
    def MakeGroupChatAdmin(
        self,
        request: conversations_pb2.MakeGroupChatAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Make a user an admin of a group chat"""

    @abc.abstractmethod
    def RemoveGroupChatUser(
        self,
        request: conversations_pb2.RemoveGroupChatUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Remove a user in a group chat."""

    @abc.abstractmethod
    def RemoveGroupChatAdmin(
        self,
        request: conversations_pb2.RemoveGroupChatAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Remove a user from admin in group chat. TODO: Only original creator can do this"""

    @abc.abstractmethod
    def SendMessage(
        self,
        request: conversations_pb2.SendMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Send a message to a group chat"""

    @abc.abstractmethod
    def SendDirectMessage(
        self,
        request: conversations_pb2.SendDirectMessageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.SendDirectMessageRes, collections.abc.Awaitable[conversations_pb2.SendDirectMessageRes]]:
        """Sends a direct message by either creating or using an existing DM chat"""

    @abc.abstractmethod
    def LeaveGroupChat(
        self,
        request: conversations_pb2.LeaveGroupChatReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Leave a group chat"""

    @abc.abstractmethod
    def SearchMessages(
        self,
        request: conversations_pb2.SearchMessagesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[conversations_pb2.SearchMessagesRes, collections.abc.Awaitable[conversations_pb2.SearchMessagesRes]]:
        """Search messages by string"""

def add_ConversationsServicer_to_server(servicer: ConversationsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jail.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2
from . import account_pb2 as account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\njail.proto\x12\x11org.couchers.jail\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\x1a\raccount.proto\"\x8f\x02\n\x0bJailInfoRes\x12\x0e\n\x06jailed\x18\x01 \x01(\x08\x12\x1c\n\x14has_not_accepted_tos\x18\x02 \x01(\x08\x12 \n\x18needs_to_update_location\x18\x03 \x01(\x08\x12-\n%has_not_accepted_community_guidelines\x18\x04 \x01(\x08\x12\x1d\n\x15has_pending_mod_notes\x18\x06 \x01(\x08\x12<\n\x11pending_mod_notes\x18\x07 \x03(\x0b\x32!.org.couchers.api.account.ModNote\x12$\n\x1chas_pending_activeness_probe\x18\x08 \x01(\x08\"\x1e\n\x0c\x41\x63\x63\x65ptTOSReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"H\n\x0eSetLocationReq\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06radius\x18\x04 \x01(\x01\".\n\x1c\x41\x63\x63\x65ptCommunityGuidelinesReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"D\n\x1c\x41\x63knowledgePendingModNoteReq\x12\x0f\n\x07note_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63knowledge\x18\x02 \x01(\x08\"[\n\x1bRespondToActivenessProbeReq\x12<\n\x08response\x18\x01 \x01(\x0e\x32*.org.couchers.jail.ActivenessProbeResponse*\x9c\x01\n\x17\x41\x63tivenessProbeResponse\x12%\n!ACTIVENESS_PROBE_RESPONSE_UNKNOWN\x10\x00\x12*\n&ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE\x10\x01\x12.\n*ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE\x10\x02\x32\xc4\x04\n\x04Jail\x12\x44\n\x08JailInfo\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12N\n\tAcceptTOS\x12\x1f.org.couchers.jail.AcceptTOSReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetLocation\x12!.org.couchers.jail.SetLocationReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63\x63\x65ptCommunityGuidelines\x12/.org.couchers.jail.AcceptCommunityGuidelinesReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63knowledgePendingModNote\x12/.org.couchers.jail.AcknowledgePendingModNoteReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12l\n\x18RespondToActivenessProbe\x12..org.couchers.jail.RespondToActivenessProbeReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x1a\x04\x88\xb5\x18\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jail_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_JAIL']._loaded_options = None
  _globals['_JAIL']._serialized_options = b'\210\265\030\002'
  _globals['_ACTIVENESSPROBERESPONSE']._serialized_start=688
  _globals['_ACTIVENESSPROBERESPONSE']._serialized_end=844
  _globals['_JAILINFORES']._serialized_start=97
  _globals['_JAILINFORES']._serialized_end=368
  _globals['_ACCEPTTOSREQ']._serialized_start=370
  _globals['_ACCEPTTOSREQ']._serialized_end=400
  _globals['_SETLOCATIONREQ']._serialized_start=402
  _globals['_SETLOCATIONREQ']._serialized_end=474
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_start=476
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_end=522
  _globals['_ACKNOWLEDGEPENDINGMODNOTEREQ']._serialized_start=524
  _globals['_ACKNOWLEDGEPENDINGMODNOTEREQ']._serialized_end=592
  _globals['_RESPONDTOACTIVENESSPROBEREQ']._serialized_start=594
  _globals['_RESPONDTOACTIVENESSPROBEREQ']._serialized_end=685
  _globals['_JAIL']._serialized_start=847
  _globals['_JAIL']._serialized_end=1427
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import pages_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class PagesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePlace(
        self,
        request: pages_pb2.CreatePlaceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Creates a place"""

    @abc.abstractmethod
    def CreateGuide(
        self,
        request: pages_pb2.CreateGuideReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Creates a guide"""

    @abc.abstractmethod
    def GetPage(
        self,
        request: pages_pb2.GetPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Gets a page"""

    @abc.abstractmethod
    def UpdatePage(
        self,
        request: pages_pb2.UpdatePageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Edit a page"""

    @abc.abstractmethod
    def TransferPage(
        self,
        request: pages_pb2.TransferPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Transfer a page you own to either a group or a community"""

    @abc.abstractmethod
    def ListUserPlaces(
        self,
        request: pages_pb2.ListUserPlacesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.ListUserPlacesRes, collections.abc.Awaitable[pages_pb2.ListUserPlacesRes]]:
        """Gets a list of places pages a user owns"""

    @abc.abstractmethod
    def ListUserGuides(
        self,
        request: pages_pb2.ListUserGuidesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.ListUserGuidesRes, collections.abc.Awaitable[pages_pb2.ListUserGuidesRes]]:
        """Gets a list of guide pages a user owns"""

def add_PagesServicer_to_server(servicer: PagesServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import discussions_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import pages_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CommunityParent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    community_id: builtins.int
    name: builtins.str
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. New York City: a guide to Phở might become
    new-york-city-guide-to-pho
    """
    description: builtins.str
    def __init__(
        self,
        *,
        community_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        description: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "description", b"description", "name", b"name", "slug", b"slug"]) -> None: ...

Global___CommunityParent: typing_extensions.TypeAlias = CommunityParent

@typing.final
class GroupParent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    name: builtins.str
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. New York City: a guide to Phở might become
    new-york-city-guide-to-pho
    """
    description: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        description: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "group_id", b"group_id", "name", b"name", "slug", b"slug"]) -> None: ...

Global___GroupParent: typing_extensions.TypeAlias = GroupParent

@typing.final
class Parent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    @property
    def community(self) -> Global___CommunityParent: ...
    @property
    def group(self) -> Global___GroupParent: ...
    def __init__(
        self,
        *,
        community: Global___CommunityParent | None = ...,
        group: Global___GroupParent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["community", b"community", "group", b"group", "parent", b"parent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["community", b"community", "group", b"group", "parent", b"parent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["parent", b"parent"]) -> typing.Literal["community", "group"] | None: ...

Global___Parent: typing_extensions.TypeAlias = Parent

@typing.final
class Group(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    PARENTS_FIELD_NUMBER: builtins.int
    MAIN_PAGE_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ADMIN_FIELD_NUMBER: builtins.int
    MEMBER_COUNT_FIELD_NUMBER: builtins.int
    ADMIN_COUNT_FIELD_NUMBER: builtins.int
    CAN_MODERATE_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    name: builtins.str
    slug: builtins.str
    """a short URL fragment generated from the name, e.g. New York City: a guide to Phở might become
    new-york-city-guide-to-pho
    """
    description: builtins.str
    member: builtins.bool
    admin: builtins.bool
    member_count: builtins.int
    admin_count: builtins.int
    can_moderate: builtins.bool
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def parents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Parent]:
        """list of parents, ordered according to inclusion, e.g. World, Australia, (East Coast Hitchhikers)"""

    @property
    def main_page(self) -> pages_pb2.Page: ...
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        name: builtins.str | None = ...,
        slug: builtins.str | None = ...,
        description: builtins.str | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        parents: collections.abc.Iterable[Global___Parent] | None = ...,
        main_page: pages_pb2.Page | None = ...,
        member: builtins.bool | None = ...,
        admin: builtins.bool | None = ...,
        member_count: builtins.int | None = ...,
        admin_count: builtins.int | None = ...,
        can_moderate: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "main_page", b"main_page"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin", b"admin", "admin_count", b"admin_count", "can_moderate", b"can_moderate", "created", b"created", "description", b"description", "group_id", b"group_id", "main_page", b"main_page", "member", b"member", "member_count", b"member_count", "name", b"name", "parents", b"parents", "slug", b"slug"]) -> None: ...

Global___Group: typing_extensions.TypeAlias = Group

@typing.final
class GetGroupReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

Global___GetGroupReq: typing_extensions.TypeAlias = GetGroupReq

@typing.final
class ListAdminsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListAdminsReq: typing_extensions.TypeAlias = ListAdminsReq

@typing.final
class ListAdminsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADMIN_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def admin_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        admin_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["admin_user_ids", b"admin_user_ids", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListAdminsRes: typing_extensions.TypeAlias = ListAdminsRes

@typing.final
class ListMembersReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListMembersReq: typing_extensions.TypeAlias = ListMembersReq

@typing.final
class ListMembersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEMBER_USER_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def member_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        member_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["member_user_ids", b"member_user_ids", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListMembersRes: typing_extensions.TypeAlias = ListMembersRes

@typing.final
class ListPlacesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListPlacesReq: typing_extensions.TypeAlias = ListPlacesReq

@typing.final
class ListPlacesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLACES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def places(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[pages_pb2.Page]: ...
    def __init__(
        self,
        *,
        places: collections.abc.Iterable[pages_pb2.Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "places", b"places"]) -> None: ...

Global___ListPlacesRes: typing_extensions.TypeAlias = ListPlacesRes

@typing.final
class ListGuidesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListGuidesReq: typing_extensions.TypeAlias = ListGuidesReq

@typing.final
class ListGuidesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GUIDES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def guides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[pages_pb2.Page]: ...
    def __init__(
        self,
        *,
        guides: collections.abc.Iterable[pages_pb2.Page] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["guides", b"guides", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListGuidesRes: typing_extensions.TypeAlias = ListGuidesRes

@typing.final
class ListEventsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAST_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    past: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        past: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token", "past", b"past"]) -> None: ...

Global___ListEventsReq: typing_extensions.TypeAlias = ListEventsReq

@typing.final
class ListEventsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[events_pb2.Event]: ...
    def __init__(
        self,
        *,
        events: collections.abc.Iterable[events_pb2.Event] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["events", b"events", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListEventsRes: typing_extensions.TypeAlias = ListEventsRes

@typing.final
class ListDiscussionsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListDiscussionsReq: typing_extensions.TypeAlias = ListDiscussionsReq

@typing.final
class ListDiscussionsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISCUSSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def discussions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[discussions_pb2.Discussion]: ...
    def __init__(
        self,
        *,
        discussions: collections.abc.Iterable[discussions_pb2.Discussion] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["discussions", b"discussions", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListDiscussionsRes: typing_extensions.TypeAlias = ListDiscussionsRes

@typing.final
class JoinGroupReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

Global___JoinGroupReq: typing_extensions.TypeAlias = JoinGroupReq

@typing.final
class LeaveGroupReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_ID_FIELD_NUMBER: builtins.int
    group_id: builtins.int
    def __init__(
        self,
        *,
        group_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_id", b"group_id"]) -> None: ...

Global___LeaveGroupReq: typing_extensions.TypeAlias = LeaveGroupReq

@typing.final
class ListUserGroupsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """the user to get groups from, set to 0 for current user"""
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "user_id", b"user_id"]) -> None: ...

Global___ListUserGroupsReq: typing_extensions.TypeAlias = ListUserGroupsReq

@typing.final
class ListUserGroupsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Group]: ...
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[Global___Group] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groups", b"groups", "next_page_token", b"next_page_token"]) -> None: ...

Global___ListUserGroupsRes: typing_extensions.TypeAlias = ListUserGroupsRes



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PhotoGalleryItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_ID_FIELD_NUMBER: builtins.int
    FULL_URL_FIELD_NUMBER: builtins.int
    THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    item_id: builtins.int
    full_url: builtins.str
    thumbnail_url: builtins.str
    caption: builtins.str
    """Photos are returned in order, no position field needed"""
    def __init__(
        self,
        *,
        item_id: builtins.int | None = ...,
        full_url: builtins.str | None = ...,
        thumbnail_url: builtins.str | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "full_url", b"full_url", "item_id", b"item_id", "thumbnail_url", b"thumbnail_url"]) -> None: ...

Global___PhotoGalleryItem: typing_extensions.TypeAlias = PhotoGalleryItem

@typing.final
class PhotoGallery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    PHOTOS_FIELD_NUMBER: builtins.int
    CAN_EDIT_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    can_edit: builtins.bool
    @property
    def photos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PhotoGalleryItem]: ...
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        photos: collections.abc.Iterable[Global___PhotoGalleryItem] | None = ...,
        can_edit: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["can_edit", b"can_edit", "gallery_id", b"gallery_id", "photos", b"photos"]) -> None: ...

Global___PhotoGallery: typing_extensions.TypeAlias = PhotoGallery

@typing.final
class GetGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id"]) -> None: ...

Global___GetGalleryReq: typing_extensions.TypeAlias = GetGalleryReq

@typing.final
class AddPhotoToGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    UPLOAD_KEY_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    upload_key: builtins.str
    caption: builtins.str
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        upload_key: builtins.str | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "gallery_id", b"gallery_id", "upload_key", b"upload_key"]) -> None: ...

Global___AddPhotoToGalleryReq: typing_extensions.TypeAlias = AddPhotoToGalleryReq

@typing.final
class RemovePhotoFromGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___RemovePhotoFromGalleryReq: typing_extensions.TypeAlias = RemovePhotoFromGalleryReq

@typing.final
class MovePhotoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    AFTER_ITEM_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    after_item_id: builtins.int
    """ID of photo to place this one after, or 0 to move to first position"""
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
        after_item_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["after_item_id", b"after_item_id", "gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___MovePhotoReq: typing_extensions.TypeAlias = MovePhotoReq

@typing.final
class UpdatePhotoCaptionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    caption: builtins.str
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___UpdatePhotoCaptionReq: typing_extensions.TypeAlias = UpdatePhotoCaptionReq

@typing.final
class GetGalleryEditInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id"]) -> None: ...

Global___GetGalleryEditInfoReq: typing_extensions.TypeAlias = GetGalleryEditInfoReq

@typing.final
class GetGalleryEditInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    MAX_PHOTOS_FIELD_NUMBER: builtins.int
    CURRENT_PHOTO_COUNT_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    max_photos: builtins.int
    current_photo_count: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        max_photos: builtins.int | None = ...,
        current_photo_count: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_photo_count", b"current_photo_count", "gallery_id", b"gallery_id", "max_photos", b"max_photos"]) -> None: ...

Global___GetGalleryEditInfoRes: typing_extensions.TypeAlias = GetGalleryEditInfoRes



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cgroups.proto\x12\x17org.couchers.api.groups\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0bpages.proto\"X\n\x0f\x43ommunityParent\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"P\n\x0bGroupParent\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x88\x01\n\x06Parent\x12=\n\tcommunity\x18\x01 \x01(\x0b\x32(.org.couchers.api.groups.CommunityParentH\x00\x12\x35\n\x05group\x18\x02 \x01(\x0b\x32$.org.couchers.api.groups.GroupParentH\x00\x42\x08\n\x06parent\"\xba\x02\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\x0c \x01(\x08\"\x1f\n\x0bGetGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"H\n\rListAdminsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x0eListMembersReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListPlacesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListGuidesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\rListEventsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"M\n\x12ListDiscussionsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\" \n\x0cJoinGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"!\n\rLeaveGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"K\n\x11ListUserGroupsReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\\\n\x11ListUserGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbe\x07\n\x06Groups\x12R\n\x08GetGroup\x12$.org.couchers.api.groups.GetGroupReq\x1a\x1e.org.couchers.api.groups.Group\"\x00\x12^\n\nListAdmins\x12&.org.couchers.api.groups.ListAdminsReq\x1a&.org.couchers.api.groups.ListAdminsRes\"\x00\x12\x61\n\x0bListMembers\x12\'.org.couchers.api.groups.ListMembersReq\x1a\'.org.couchers.api.groups.ListMembersRes\"\x00\x12^\n\nListPlaces\x12&.org.couchers.api.groups.ListPlacesReq\x1a&.org.couchers.api.groups.ListPlacesRes\"\x00\x12^\n\nListGuides\x12&.org.couchers.api.groups.ListGuidesReq\x1a&.org.couchers.api.groups.ListGuidesRes\"\x00\x12^\n\nListEvents\x12&.org.couchers.api.groups.ListEventsReq\x1a&.org.couchers.api.groups.ListEventsRes\"\x00\x12m\n\x0fListDiscussions\x12+.org.couchers.api.groups.ListDiscussionsReq\x1a+.org.couchers.api.groups.ListDiscussionsRes\"\x00\x12L\n\tJoinGroup\x12%.org.couchers.api.groups.JoinGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\nLeaveGroup\x12&.org.couchers.api.groups.LeaveGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x0eListUserGroups\x12*.org.couchers.api.groups.ListUserGroupsReq\x1a*.org.couchers.api.groups.ListUserGroupsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'groups_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GROUPS']._loaded_options = None
  _globals['_GROUPS']._serialized_options = b'\210\265\030\003'
  _globals['_COMMUNITYPARENT']._serialized_start=168
  _globals['_COMMUNITYPARENT']._serialized_end=256
  _globals['_GROUPPARENT']._serialized_start=258
  _globals['_GROUPPARENT']._serialized_end=338
  _globals['_PARENT']._serialized_start=341
  _globals['_PARENT']._serialized_end=477
  _globals['_GROUP']._serialized_start=480
  _globals['_GROUP']._serialized_end=794
  _globals['_GETGROUPREQ']._serialized_start=796
  _globals['_GETGROUPREQ']._serialized_end=827
  _globals['_LISTADMINSREQ']._serialized_start=829
  _globals['_LISTADMINSREQ']._serialized_end=901
  _globals['_LISTADMINSRES']._serialized_start=903
  _globals['_LISTADMINSRES']._serialized_end=967
  _globals['_LISTMEMBERSREQ']._serialized_start=969
  _globals['_LISTMEMBERSREQ']._serialized_end=1042
  _globals['_LISTMEMBERSRES']._serialized_start=1044
  _globals['_LISTMEMBERSRES']._serialized_end=1110
  _globals['_LISTPLACESREQ']._serialized_start=1112
  _globals['_LISTPLACESREQ']._serialized_end=1184
  _globals['_LISTPLACESRES']._serialized_start=1186
  _globals['_LISTPLACESRES']._serialized_end=1272
  _globals['_LISTGUIDESREQ']._serialized_start=1274
  _globals['_LISTGUIDESREQ']._serialized_end=1346
  _globals['_LISTGUIDESRES']._serialized_start=1348
  _globals['_LISTGUIDESRES']._serialized_end=1434
  _globals['_LISTEVENTSREQ']._serialized_start=1436
  _globals['_LISTEVENTSREQ']._serialized_end=1522
  _globals['_LISTEVENTSRES']._serialized_start=1524
  _globals['_LISTEVENTSRES']._serialized_end=1612
  _globals['_LISTDISCUSSIONSREQ']._serialized_start=1614
  _globals['_LISTDISCUSSIONSREQ']._serialized_end=1691
  _globals['_LISTDISCUSSIONSRES']._serialized_start=1693
  _globals['_LISTDISCUSSIONSRES']._serialized_end=1801
  _globals['_JOINGROUPREQ']._serialized_start=1803
  _globals['_JOINGROUPREQ']._serialized_end=1835
  _globals['_LEAVEGROUPREQ']._serialized_start=1837
  _globals['_LEAVEGROUPREQ']._serialized_end=1870
  _globals['_LISTUSERGROUPSREQ']._serialized_start=1872
  _globals['_LISTUSERGROUPSREQ']._serialized_end=1947
  _globals['_LISTUSERGROUPSRES']._serialized_start=1949
  _globals['_LISTUSERGROUPSRES']._serialized_end=2041
  _globals['_GROUPS']._serialized_start=2044
  _globals['_GROUPS']._serialized_end=3002
# @@protoc_insertion_point(module_scope)
